#
# spec file for package xman
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xman
Version:        1.2.0
Release:        1.5
Summary:        Manual page display program for the X Window System
License:        MIT
Group:          System/X11/Utilities
URL:            https://xorg.freedesktop.org/
Source0:        https://xorg.freedesktop.org/releases/individual/app/%{name}-%{version}.tar.xz
Source1:        https://xorg.freedesktop.org/releases/individual/app/%{name}-%{version}.tar.xz.sig
Source2:        xman.keyring
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(xaw7)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
BuildRequires:  pkgconfig(xproto) >= 7.0.17
BuildRequires:  pkgconfig(xt)
# This was part of the xorg-x11 package up to version 7.6
Conflicts:      xorg-x11 <= 7.6

%description
xman is a graphical manual page browser.

%prep
%setup -q

%build
%configure
%make_build

%install
%make_install

%files
%license COPYING
%doc ChangeLog README.md
%{_bindir}/xman
%dir %{_datadir}/X11/app-defaults
%{_datadir}/X11/app-defaults/Xman
%{_datadir}/X11/xman.help
%{_mandir}/man1/xman.1%{?ext_man}

%changelog
* Mon Mar 25 2024 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.2.0
  * This release improves the display of the formatted man page
    when using man-db, fixes a memory leak when closing a man page,
    and removes support for a number of OS'es from the 80's & 90's,
    along with removing support for using Xprint to print a man
    page.
* Fri Sep 29 2023 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.1.6
  * This release adds a -version option and fixes
    https://bugs.debian.org/720266
* Thu Aug 11 2022 Dirk Müller <dmueller@suse.com>
- use gpg for source validation
* Fri Dec  3 2021 Dirk Müller <dmueller@suse.com>
- modernize spec file (move license to licensedir)
* Mon Jul 15 2019 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.1.5:
  * autogen: add default patch prefix
  * autogen.sh: use quoted string variables
  * autogen.sh: use exec instead of waiting for configure to finish
  * Update configure.ac bug URL for gitlab migration
  * Change fall through comment in ScrollByL.c to match gcc's requirements
  * Delete unused function Name() from tkfuncs.c
  * Make CreateManpageWidget use String type for name argument
  * Change fallback_resources from char * to String type
  * Pass -D_CONST_X_STRING to make libXt declare String as const char *
  * If we have man-db, don't try and emulate man's pipeline
  * Fix typo in manual page.
  * Update README for gitlab migration
* Sun Mar  8 2015 zaitor@opensuse.org
- Update to version 1.1.4:
  + Ask groff for text instead of postscript on Solaris.
  + Fix typos & wording issues in source comments.
  + autogen.sh: Honor NOCONFIGURE=1.
  + configure: Drop AM_MAINTAINER_MODE.
  + config: Add missing AC_CONFIG_SRCDIR.
  + Fix shadow warning.
  + Fix tautology to the intended check.
  + Use same FORMAT command on cygwin as on linux in HANDLE_ROFFSEQ
    case as well.
  + Ensure fgets read at least one byte before modifying string.
  + Fix "no search will be preformed" typo in dialog box message.
* Sat Sep  7 2013 zaitor@opensuse.org
- Update to version 1.1.3:
  + COPYING: Remove notice for Xprint.
  + Check for CreateManpage returning NULL.
  + Check for InitPsuedoGlobals() returning NULL.
  + Close file pointer before setting it to NULL in Format().
    Avoids more file leaks.
  + Fix file leak in ConstructCommand().
  + configure: check for groff and enable groff extensions if
    found.
  + Provide a fallback mkstemp so we don't need to maintain 2 API
    versions.
  + Fix scroll wheel when CapsLock, NumLock or other modifiers are
    on.
  + Increase default text window sizes from 600 to 780 pixels.
  + Stop checking for OSMINORVERSION in list of Solaris man page
    sections.
  + Replace StrAlloc with XtNewString.
  + Remove XConsortium/XFree86/XdotOrg RCS/CVS id tags.
  + Convert to X.Org standard code style.
  + Fix numerous typos & spelling errors in comments and message
    strings.
  + Use <dirent.h> everywhere instead of checking for
    X_NOT_POSIX/SYSV/USG/etc.
  + Eliminate use of tab stops.  Use real TBL markup where
    indicated.
  + Rename PIC to ROFF_PIC to avoid problems with "-DPIC"
    compilations.
* Sat Apr 14 2012 dimstar@opensuse.org
- Update to version 1.1.2:
  + Remove xmu dependency by inlining AssignMax macro.
  + Use snprintf to PATH_MAX sized buffers to construct filenames.
  + Convert more sprintf calls to snprintf.
  + Don't need to copy static strings to a buffer before calling
    PopupWarning.
  + Mark string argument to PopupWarning as a const char *.
  + Build system fixes.
- Remove pkgconfig(xmu) BuildRequires.
* Fri Apr 13 2012 vuntz@opensuse.org
- Split xman from xorg-x11. Initial version: 1.1.1.
